@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-#coding=utf-8
-
+# -*- coding: utf-8 -*-
 #
 # Copyright (C) 2014 - S. Zachariah Sprackett <zac@sprackett.com>
 #
@@ -9,8 +8,10 @@
 
 import sys
 
+
 class ExitHook(object):
     def __init__(self):
+        self._orig_exit = None
         self.exit_code = None
         self.exception = None
 
@@ -23,5 +24,5 @@ class ExitHook(object):
         self.exit_code = code
         self._orig_exit(code)
 
-    def exc_handler(self, exc_type, exc, *args):
+    def exc_handler(self, _exc_type, exc, *_args):
         self.exception = exc
